<?php
/**
 * Ce fichier contient l'action `actionner_historisation` lancée par un utilisateur pour
 * activer ou désactiver, supprimer ou vider une historisation de façon sécurisée.
 */
if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

/**
 * Cette action permet à l'utilisateur d'activer ou de désactiver, de supprimer ou de vider, de façon sécurisée,
 * une historisation donnée.
 *
 * Cette action est réservée aux utilisateurs pouvant créer ou modifier une historisation.
 * Elle nécessite l'identifiant de l'historisation et l'identifiant de l'action à exécuter.
 *
 * @param null|string $arguments Arguments de l'action ou null si l'action est appelée par une URL
 *
 * @return void
 */
function action_actionner_historisation_dist(?string $arguments = null) : void {
	// Sécurisation.
	// Arguments attendus :
	// - identifiant de l'action
	// - identifiant de l'historisation
	if (null === $arguments) {
		$securiser_action = charger_fonction('securiser_action', 'inc');
		$arguments = $securiser_action();
	}

	// Récupération des arguments
	[$action, $histo_id] = explode(':', $arguments);

	// Verification des autorisations :
	if (!autoriser('modifier', 'historisation', $histo_id)) {
		include_spip('inc/minipres');
		echo minipres();
		exit();
	}

	// On traite l'action
	if (
		$histo_id
		and include_spip('inc/config')
		and ($historisation = lire_config("rainette_historisations/{$histo_id}"))
	) {
		if ($action === 'inverser_activite') {
			// Activité
			// -- on inverse l'activité
			$historisation['active'] = !$historisation['active'];
			// -- on loge le changement dans le log d'activité
			$date = date('Y-m-d H:s:i', time());
			$historisation['log_activite'][$date] = $historisation['active']
				? _T('rainette:log_histo_activation')
				: _T('rainette:log_histo_desactivation');
			// -- on met à jour l'historisation
			ecrire_config("rainette_historisations/{$histo_id}", $historisation);
		} elseif ($action === 'supprimer') {
			// Suppression
			// -- on supprime l'historisation sans vider les historiques
			effacer_config("rainette_historisations/{$histo_id}");
		}
	}
}
