<?php

/**
 * Gestion du formulaire d'administration des feeds d'un plugin utilisateur.
 */
if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

/**
 * Chargement du formulaire d'administration des historisations.
 *
 * @param null|string $histo_id Identificant de l'historisation servant à l'affichage du bloc de détails
 * @param null|string $redirect URL de base du privé vers où se rendre en sortant du formulaire
 *
 * @return array Environnement du formulaire
 **/
function formulaires_admin_historisations_charger_dist(?string $histo_id = '', ?string $redirect = 'historisations') {
	$valeurs = [
		'editable' => true
	];

	if (autoriser('voir', '_historisations')) {
		// On passe le nombre d'historisations définies
		include_spip('inc/config');
		$historisations = lire_config('rainette_historisations', []);
		$valeurs['nbr_histo'] = count($historisations);

		// On passe l'id si il existe
		$valeurs['histo_id'] = $histo_id;
	} else {
		$valeurs['message_erreur'] = _T('rainette:erreur_histo_admin_noaccess');
		$valeurs['editable'] = false;
	}

	return $valeurs;
}

/**
 * Traitement du formulaire d'administration des historisations.
 *
 * @param null|string $histo_id Identificant de l'historisation servant à l'affichage du bloc de détails
 * @param null|string $redirect URL de base du privé vers où se rendre en sortant du formulaire
 *
 * @return array Retour du traitement : rien de spécial car pour l'instant, il n'est pas utilisé
 **/
function formulaires_admin_historisations_traiter_dist(?string $histo_id = '', ?string $redirect = 'historisations') {
	$retour = [];

	// On récupère l'action et l'identifiant de l'historisation concernée
	$action = '';
	$id_histo = '';
	foreach (['inverser_activite', 'supprimer'] as $_action) {
		if ($action_form = _request($_action)) {
			$action = $_action;
			$id_histo = key($action_form);
			break;
		}
	}

	if (
		$action
		and $id_histo
	) {
		$actionner = charger_fonction(
			'actionner_historisation',
			'action',
			true
		);

		// Lancer l'action avec les arguments nécessaires
		$actionner("{$action}:{$id_histo}");
	}

	$retour['editable'] = true;

	return $retour;
}
