<?php
/**
 * Fichier gérant l'installation et désinstallation du plugin Rainette.
 *
 * @package    SPIP\RAINETTE\INSTALLATION
 */
if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

/**
 * Fonction d'installation de Historisation de Rainette.
 *
 * @param string $nom_meta_base_version Nom de la meta informant de la version du schéma de données du plugin
 *                                      installé dans SPIP
 * @param string $version_cible         Version du schéma de données dans ce plugin (déclaré dans paquet.xml)
 *
 * @return void
**/
function rainette_histo_upgrade(string $nom_meta_base_version, string $version_cible) : void {
	// A la création on crée la table d'historiques et le paramétrage utilisateur par défaut (réserve)
	$config_defaut = [];
	$maj['create'] = [
		['maj_tables', ['spip_rainette_historiques']],
		['ecrire_config', 'rainette_histo', $config_defaut],
	];

	include_spip('base/upgrade');
	maj_plugin($nom_meta_base_version, $version_cible, $maj);
}

/**
 * Fonction de désinstallation du plugin Rainette (suppression des metas).
 *
 * @param string $nom_meta_base_version Nom de la meta informant de la version du schéma de données du plugin
 *                                      installé dans SPIP
 *
 * @return void
**/
function rainette_histo_vider_tables(string $nom_meta_base_version) : void {
	// On efface les tables du plugin
	sql_drop_table('spip_rainette_historiques');

	// Effacer les meta du plugin
	// - la liste des historisations
	effacer_meta('rainette_historisations');
	// - le paramétrage utilisateur
	effacer_meta('rainette_histo');
	// - la meta de schéma
	effacer_meta($nom_meta_base_version);
}
