<?php
/**
 * Ce fichier contient les fonctions d'autorisations du plugin.
 */
if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

/**
 * Fonction appelée par le pipeline.
 */
function rainette_histo_autoriser() {
}

/**
 * Autorisation de voir la liste des historisations.
 * Il faut posséder l'autorisation minimale `configurer` qui est l'autorisation de base de la configuration de Rainette.
 *
 * @param string         $faire   L'action : `voir`
 * @param string         $type    Le type d'objet ou nom de table : `_historisations` (ce n'est pas un objet au sens SPIP)
 * @param int            $id      Id de l'objet sur lequel on veut agir : 0, inutilisé
 * @param null|array|int $qui     L'initiateur de l'action:
 *                                - si null on prend alors visiteur_session
 *                                - un id_auteur (on regarde dans la base)
 *                                - un tableau auteur complet, y compris [restreint]
 * @param null|array     $options Tableau d'options sous forme de tableau associatif : inutilisé
 *
 * @return bool `true`si l'auteur est autorisée à exécuter l'action, `false` sinon.
 */
function autoriser_historisations_voir_dist($faire, $type, $id, $qui, $options) {
	return autoriser('configurer');
}

/**
 * Autorisation de créer une historisation.
 * Il faut :
 * - posséder l'autorisation minimale `configurer`.
 *
 * @param string         $faire   Action demandée : `creer`
 * @param string         $type    Le type d'objet ou nom de table : `historisation` (ce n'est pas un objet au sens SPIP)
 * @param int            $id      Identifiant de l'objet : `0`, inutilisé
 * @param null|array|int $qui     L'initiateur de l'action:
 *                                - si null on prend alors visiteur_session
 *                                - un id_auteur (on regarde dans la base)
 *                                - un tableau auteur complet, y compris [restreint]
 * @param null|array     $options Tableau d'options sous forme de tableau associatif : inutilisé
 *
 * @return bool `true`si l'auteur est autorisée à exécuter l'action, `false` sinon.
**/
function autoriser_historisation_creer_dist($faire, $type, $id, $qui, $options) {
	return autoriser('configurer');
}

/**
 * Autorisation de modifier les paramètres d'une historisation.
 * Il faut :
 * - posséder l'autorisation minimale `configurer`.
 * - fournir un identifiant d'une historisation existante.
 *
 * @param string         $faire   Action demandée : `modifier` (pour activer/désactiver et supprimer)
 * @param string         $type    Type d'objet sur lequel appliquer l'action : `historisation`
 * @param int            $id      Identifiant de l'historisation sur laquelle appliquer l'action
 * @param null|array|int $qui     L'initiateur de l'action:
 *                                - si null on prend alors visiteur_session
 *                                - un id_auteur (on regarde dans la base)
 *                                - un tableau auteur complet, y compris [restreint]
 * @param null|array     $options Tableau d'options sous forme de tableau associatif : inutilisé
 *
 * @return bool `true`si l'auteur est autorisée à exécuter l'action, `false` sinon.
**/
function autoriser_historisation_modifier_dist($faire, $type, $id, $qui, $options) {
	// Initialisation de l'autorisation à non autorisé par défaut.
	$autorise = false;

	if (
		autoriser('configurer')
		and $id
		and is_string($id)
		and include_spip('inc/config')
		and lire_config("rainette_historisations/{$id}", [])
	) {
		$autorise = true;
	}

	return $autorise;
}
